pub fn accumulate_buffs(
state: &CombatState,
buf: &DenseBuffer,
target: Option<EnemyIdx>,
) -> BuffTotalsExpand description
Sum all active aura buff contributions, scaled by stack count.
pub fn accumulate_buffs(
state: &CombatState,
buf: &DenseBuffer,
target: Option<EnemyIdx>,
) -> BuffTotalsSum all active aura buff contributions, scaled by stack count.