pub struct DamageFlags(<DamageFlags as PublicFlags>::Internal);Expand description
Semantics of a damage impact. Empty is magical, player-sourced, direct, and crit-capable.
Tuple Fields
0: <DamageFlags as PublicFlags>::InternalImplementations
Sourceimpl DamageFlags
impl DamageFlags
pub const PHYSICAL: Self
Sourcepub const PET: Self
pub const PET: Self
Companion-owned impact; guardians carry it for pet scaling, telemetry, and proc suppression.
pub const PERIODIC: Self
pub const NO_CRIT: Self
Sourcepub const GUARDIAN: Self
pub const GUARDIAN: Self
Temporary-guardian subtype, set with PET so target modifiers can distinguish guardians.
pub const IGNORE_PLAYER_MULTIPLIERS: Self
pub const IGNORE_TARGET_MULTIPLIERS: Self
pub const IGNORE_POSITIVE_TARGET_MULTIPLIERS: Self
pub const PROC: Self
Sourcepub const REPORT_AS_PROFILE: Self
pub const REPORT_AS_PROFILE: Self
Attribute telemetry to the action while retaining the payload for runtime mechanics.
Sourcepub const AOE: Self
pub const AOE: Self
Area damage, including DBC spells explicitly tagged to use area-effect semantics.
Sourcepub const REFLECTION_RESOLVED: Self
pub const REFLECTION_RESOLVED: Self
The target’s reflect/deflect decision has already been resolved for this impact.
Sourcepub const REFLECTED: Self
pub const REFLECTED: Self
Re-execute this impact against its caster without another reflection check.
Sourcepub const IGNORE_CRIT_DAMAGE_BONUSES: Self
pub const IGNORE_CRIT_DAMAGE_BONUSES: Self
Preserve crit chance while suppressing bonuses beyond the baseline 2x crit damage.
Sourceimpl DamageFlags
impl DamageFlags
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl DamageFlags
impl DamageFlags
Sourcepub const fn iter(&self) -> Iter<DamageFlags>
pub const fn iter(&self) -> Iter<DamageFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DamageFlags>
pub const fn iter_names(&self) -> IterNames<DamageFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.